@@ -2,10 +2,9 @@ package TOML::Parser;
 use 5.008005;
 use strict;
 use warnings;
-use utf8;
 use Encode;
 
-our $VERSION = "0.04";
+our $VERSION = "0.05";
 
 use TOML::Parser::Tokenizer qw/:constant/;
 use TOML::Parser::Tokenizer::Strict;
@@ -275,4 +274,8 @@ it under the same terms as Perl itself.
 
 karupanerura E<lt>karupa@cpan.orgE<gt>
 
+=head1 CONTRIBUTOR
+
+Olivier Mengué E<lt>dolmen@cpan.orgE<gt>
+
 =cut
